==> quollr_0.3.7.tar.gz: quollr/tests/testthat/_snaps/projection.md <==
# gen_axes() works

    Code
      gen_axes(proj = projection_df, axis_labels = paste0("x", 1:7))
    Output
      $axes
                 x1         y1         x2         y2    distance
      x1 -0.6666667 -0.6666667 -0.6955883 -0.6842517 0.033848117
      x2 -0.6666667 -0.6666667 -0.6715100 -0.6419517 0.025185097
      x3 -0.6666667 -0.6666667 -0.6335717 -0.6701050 0.033273130
      x4 -0.6666667 -0.6666667 -0.6666050 -0.6622367 0.004430429
      x5 -0.6666667 -0.6666667 -0.6664483 -0.6719167 0.005254538
      x6 -0.6666667 -0.6666667 -0.6750317 -0.6338367 0.033878933
      x7 -0.6666667 -0.6666667 -0.6610483 -0.6665933 0.005618812
      
      $circle
                 c1         c2
      1  -0.5000000 -0.6666667
      2  -0.5013683 -0.6453538
      3  -0.5054509 -0.6243909
      4  -0.5121805 -0.6041222
      5  -0.5214469 -0.5848804
      6  -0.5330977 -0.5669816
      7  -0.5469418 -0.5507196
      8  -0.5627517 -0.5363614
      9  -0.5802679 -0.5241429
      10 -0.5992028 -0.5142646
      11 -0.6192454 -0.5068887
      12 -0.6400667 -0.5021364
      13 -0.6613247 -0.5000856
      14 -0.6826705 -0.5007701
      15 -0.7037535 -0.5041787
      16 -0.7242275 -0.5102553
      17 -0.7437564 -0.5189001
      18 -0.7620194 -0.5299713
      19 -0.7787168 -0.5432870
      20 -0.7935743 -0.5586286
      21 -0.8063480 -0.5757442
      22 -0.8168281 -0.5943527
      23 -0.8248426 -0.6141486
      24 -0.8302599 -0.6348069
      25 -0.8329909 -0.6559883
      26 -0.8329909 -0.6773450
      27 -0.8302599 -0.6985264
      28 -0.8248426 -0.7191847
      29 -0.8168281 -0.7389806
      30 -0.8063480 -0.7575892
      31 -0.7935743 -0.7747047
      32 -0.7787168 -0.7900463
      33 -0.7620194 -0.8033620
      34 -0.7437564 -0.8144332
      35 -0.7242275 -0.8230781
      36 -0.7037535 -0.8291547
      37 -0.6826705 -0.8325632
      38 -0.6613247 -0.8332477
      39 -0.6400667 -0.8311970
      40 -0.6192454 -0.8264446
      41 -0.5992028 -0.8190688
      42 -0.5802679 -0.8091905
      43 -0.5627517 -0.7969719
      44 -0.5469418 -0.7826138
      45 -0.5330977 -0.7663518
      46 -0.5214469 -0.7484529
      47 -0.5121805 -0.7292112
      48 -0.5054509 -0.7089424
      49 -0.5013683 -0.6879795
      50 -0.5000000 -0.6666667
      

---

    Code
      get_projection(projection = projection_df, proj_scale = 1, highd_data = scurve,
        model_highd = df_bin, trimesh_data = edge_data, axis_param = list(limits = 1,
          axis_scaled = 3, axis_pos_x = -0.72, axis_pos_y = -0.72, threshold = 0.09))
    Message
      New names:
      * `` -> `...1`
      * `` -> `...2`
      New names:
      * `` -> `...1`
      * `` -> `...2`
    Output
      $projected_df
      # A tibble: 1,000 x 3
            proj1  proj2    ID
            <dbl>  <dbl> <int>
       1 -0.400   0.182      1
       2  0.00561 0.0247     2
       3  0.187   0.174      3
       4 -0.276   0.231      4
       5 -0.320   0.243      5
       6 -0.509   0.221      6
       7  0.0934  0.0246     7
       8 -0.0438  0.294      8
       9 -0.284   0.116      9
      10  0.147   0.289     10
      # i 990 more rows
      
      $model_df
      # A tibble: 10 x 12
          from    to x_from y_from  x_to  y_to from_count to_count proj1_from
         <int> <int>  <dbl>  <dbl> <dbl> <dbl>      <dbl>    <dbl>      <dbl>
       1     2     6  0.442 0.101  0.400 0.173         11       11     0.0869
       2     2     3  0.442 0.101  0.526 0.101         11       12     0.0869
       3     7     8  0.567 0.173  0.651 0.173         14       11     0.341 
       4     1     4  0.818 0.0288 0.776 0.101         12       12     0.401 
       5     4     5  0.776 0.101  0.859 0.101         12       12     0.427 
       6     9    10  0.776 0.245  0.734 0.318         11       12     0.440 
       7    11    12  0.400 0.751  0.442 0.823         11       12     0.0303
       8    13    14  0.109 1.11   0.192 1.11          13       14     0.248 
       9     3     7  0.526 0.101  0.567 0.173         12       14     0.389 
      10     1     5  0.818 0.0288 0.859 0.101         12       12     0.401 
      # i 3 more variables: proj2_from <dbl>, proj1_to <dbl>, proj2_to <dbl>
      
      $axes
            x1    y1        x2        y2   distance
      x1 -0.72 -0.72 -0.806765 -0.772755 0.10154435
      x3 -0.72 -0.72 -0.620715 -0.730315 0.09981939
      x6 -0.72 -0.72 -0.745095 -0.621510 0.10163680
      
      $circle
                 c1         c2
      1  -0.5533333 -0.7200000
      2  -0.5547017 -0.6986871
      3  -0.5587842 -0.6777242
      4  -0.5655139 -0.6574555
      5  -0.5747802 -0.6382137
      6  -0.5864311 -0.6203149
      7  -0.6002751 -0.6040529
      8  -0.6160850 -0.5896948
      9  -0.6336012 -0.5774762
      10 -0.6525361 -0.5675979
      11 -0.6725787 -0.5602220
      12 -0.6934000 -0.5554697
      13 -0.7146581 -0.5534190
      14 -0.7360038 -0.5541035
      15 -0.7570868 -0.5575120
      16 -0.7775608 -0.5635886
      17 -0.7970897 -0.5722334
      18 -0.8153528 -0.5833046
      19 -0.8320501 -0.5966203
      20 -0.8469077 -0.6119619
      21 -0.8596814 -0.6290775
      22 -0.8701615 -0.6476860
      23 -0.8781760 -0.6674820
      24 -0.8835932 -0.6881402
      25 -0.8863242 -0.7093216
      26 -0.8863242 -0.7306784
      27 -0.8835932 -0.7518598
      28 -0.8781760 -0.7725180
      29 -0.8701615 -0.7923140
      30 -0.8596814 -0.8109225
      31 -0.8469077 -0.8280381
      32 -0.8320501 -0.8433797
      33 -0.8153528 -0.8566954
      34 -0.7970897 -0.8677666
      35 -0.7775608 -0.8764114
      36 -0.7570868 -0.8824880
      37 -0.7360038 -0.8858965
      38 -0.7146581 -0.8865810
      39 -0.6934000 -0.8845303
      40 -0.6725787 -0.8797780
      41 -0.6525361 -0.8724021
      42 -0.6336012 -0.8625238
      43 -0.6160850 -0.8503052
      44 -0.6002751 -0.8359471
      45 -0.5864311 -0.8196851
      46 -0.5747802 -0.8017863
      47 -0.5655139 -0.7825445
      48 -0.5587842 -0.7622758
      49 -0.5547017 -0.7413129
      50 -0.5533333 -0.7200000

==> quollr_0.3.13.tar.gz: quollr/tests/testthat/_snaps/projection.md <==
# gen_axes() works

    Code
      gen_axes(proj = projection_df, axis_labels = paste0("x", 1:7))
    Output
      $axes
                 x1         y1         x2         y2    distance
      x1 -0.6666667 -0.6666667 -0.6955883 -0.6842517 0.033848117
      x2 -0.6666667 -0.6666667 -0.6715100 -0.6419517 0.025185097
      x3 -0.6666667 -0.6666667 -0.6335717 -0.6701050 0.033273130
      x4 -0.6666667 -0.6666667 -0.6666050 -0.6622367 0.004430429
      x5 -0.6666667 -0.6666667 -0.6664483 -0.6719167 0.005254538
      x6 -0.6666667 -0.6666667 -0.6750317 -0.6338367 0.033878933
      x7 -0.6666667 -0.6666667 -0.6610483 -0.6665933 0.005618812
      
      $circle
                 c1         c2
      1  -0.5000000 -0.6666667
      2  -0.5013683 -0.6453538
      3  -0.5054509 -0.6243909
      4  -0.5121805 -0.6041222
      5  -0.5214469 -0.5848804
      6  -0.5330977 -0.5669816
      7  -0.5469418 -0.5507196
      8  -0.5627517 -0.5363614
      9  -0.5802679 -0.5241429
      10 -0.5992028 -0.5142646
      11 -0.6192454 -0.5068887
      12 -0.6400667 -0.5021364
      13 -0.6613247 -0.5000856
      14 -0.6826705 -0.5007701
      15 -0.7037535 -0.5041787
      16 -0.7242275 -0.5102553
      17 -0.7437564 -0.5189001
      18 -0.7620194 -0.5299713
      19 -0.7787168 -0.5432870
      20 -0.7935743 -0.5586286
      21 -0.8063480 -0.5757442
      22 -0.8168281 -0.5943527
      23 -0.8248426 -0.6141486
      24 -0.8302599 -0.6348069
      25 -0.8329909 -0.6559883
      26 -0.8329909 -0.6773450
      27 -0.8302599 -0.6985264
      28 -0.8248426 -0.7191847
      29 -0.8168281 -0.7389806
      30 -0.8063480 -0.7575892
      31 -0.7935743 -0.7747047
      32 -0.7787168 -0.7900463
      33 -0.7620194 -0.8033620
      34 -0.7437564 -0.8144332
      35 -0.7242275 -0.8230781
      36 -0.7037535 -0.8291547
      37 -0.6826705 -0.8325632
      38 -0.6613247 -0.8332477
      39 -0.6400667 -0.8311970
      40 -0.6192454 -0.8264446
      41 -0.5992028 -0.8190688
      42 -0.5802679 -0.8091905
      43 -0.5627517 -0.7969719
      44 -0.5469418 -0.7826138
      45 -0.5330977 -0.7663518
      46 -0.5214469 -0.7484529
      47 -0.5121805 -0.7292112
      48 -0.5054509 -0.7089424
      49 -0.5013683 -0.6879795
      50 -0.5000000 -0.6666667
      

---

    Code
      get_projection(projection = projection_df, proj_scale = 1, highd_data = scurve,
        model_highd = df_bin, trimesh_data = edge_data, axis_param = list(limits = 1,
          axis_scaled = 3, axis_pos_x = -0.72, axis_pos_y = -0.72, threshold = 0.09))
    Message
      New names:
      * `` -> `...1`
      * `` -> `...2`
      New names:
      * `` -> `...1`
      * `` -> `...2`
    Output
      $projected_df
      # A tibble: 1,000 x 3
            proj1  proj2    ID
            <dbl>  <dbl> <int>
       1 -0.400   0.182      1
       2  0.00561 0.0247     2
       3  0.187   0.174      3
       4 -0.276   0.231      4
       5 -0.320   0.243      5
       6 -0.509   0.221      6
       7  0.0934  0.0246     7
       8 -0.0438  0.294      8
       9 -0.284   0.116      9
      10  0.147   0.289     10
      # i 990 more rows
      
      $model_df
      # A tibble: 346 x 14
          from    to x_from y_from  x_to   y_to from_count to_count from_reindexed
         <int> <int>  <dbl>  <dbl> <dbl>  <dbl>      <dbl>    <dbl>          <int>
       1    35    49  0.234 0.0288 0.192 0.101          10       11              2
       2    34    35  0.150 0.0288 0.234 0.0288          1       10              1
       3    49    65  0.192 0.101  0.234 0.173          11       10              8
       4    35    36  0.234 0.0288 0.317 0.0288         10        8              2
       5    64    65  0.150 0.173  0.234 0.173           5       10             17
       6    35    50  0.234 0.0288 0.275 0.101          10        9              2
       7    64    79  0.150 0.173  0.192 0.245           5       10             17
       8    36    50  0.317 0.0288 0.275 0.101           8        9              3
       9    78    94  0.109 0.245  0.150 0.318           1       11             27
      10    78    79  0.109 0.245  0.192 0.245           1       10             27
      # i 336 more rows
      # i 5 more variables: to_reindexed <int>, proj1_from <dbl>, proj2_from <dbl>,
      #   proj1_to <dbl>, proj2_to <dbl>
      
      $axes
            x1    y1        x2        y2   distance
      x1 -0.72 -0.72 -0.806765 -0.772755 0.10154435
      x3 -0.72 -0.72 -0.620715 -0.730315 0.09981939
      x6 -0.72 -0.72 -0.745095 -0.621510 0.10163680
      
      $circle
                 c1         c2
      1  -0.5533333 -0.7200000
      2  -0.5547017 -0.6986871
      3  -0.5587842 -0.6777242
      4  -0.5655139 -0.6574555
      5  -0.5747802 -0.6382137
      6  -0.5864311 -0.6203149
      7  -0.6002751 -0.6040529
      8  -0.6160850 -0.5896948
      9  -0.6336012 -0.5774762
      10 -0.6525361 -0.5675979
      11 -0.6725787 -0.5602220
      12 -0.6934000 -0.5554697
      13 -0.7146581 -0.5534190
      14 -0.7360038 -0.5541035
      15 -0.7570868 -0.5575120
      16 -0.7775608 -0.5635886
      17 -0.7970897 -0.5722334
      18 -0.8153528 -0.5833046
      19 -0.8320501 -0.5966203
      20 -0.8469077 -0.6119619
      21 -0.8596814 -0.6290775
      22 -0.8701615 -0.6476860
      23 -0.8781760 -0.6674820
      24 -0.8835932 -0.6881402
      25 -0.8863242 -0.7093216
      26 -0.8863242 -0.7306784
      27 -0.8835932 -0.7518598
      28 -0.8781760 -0.7725180
      29 -0.8701615 -0.7923140
      30 -0.8596814 -0.8109225
      31 -0.8469077 -0.8280381
      32 -0.8320501 -0.8433797
      33 -0.8153528 -0.8566954
      34 -0.7970897 -0.8677666
      35 -0.7775608 -0.8764114
      36 -0.7570868 -0.8824880
      37 -0.7360038 -0.8858965
      38 -0.7146581 -0.8865810
      39 -0.6934000 -0.8845303
      40 -0.6725787 -0.8797780
      41 -0.6525361 -0.8724021
      42 -0.6336012 -0.8625238
      43 -0.6160850 -0.8503052
      44 -0.6002751 -0.8359471
      45 -0.5864311 -0.8196851
      46 -0.5747802 -0.8017863
      47 -0.5655139 -0.7825445
      48 -0.5587842 -0.7622758
      49 -0.5547017 -0.7413129
      50 -0.5533333 -0.7200000
